summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMoonchild <moonchild@palemoon.org>2020-08-24 09:56:03 +0000
committerMoonchild <moonchild@palemoon.org>2020-08-30 09:40:03 +0000
commit3f14e9ec5ff982424f6ac2cf401037e3f749e6a3 (patch)
tree66bca74499ea7009f029eed5d048ff743f98dfba
parentaefb293793a4278d53d39e346aaa1178975aada1 (diff)
downloadUXP-3f14e9ec5ff982424f6ac2cf401037e3f749e6a3.tar
UXP-3f14e9ec5ff982424f6ac2cf401037e3f749e6a3.tar.gz
UXP-3f14e9ec5ff982424f6ac2cf401037e3f749e6a3.tar.lz
UXP-3f14e9ec5ff982424f6ac2cf401037e3f749e6a3.tar.xz
UXP-3f14e9ec5ff982424f6ac2cf401037e3f749e6a3.zip
Issue #618 - Rename some script load request flags to be more descriptive.
-rw-r--r--dom/script/ScriptLoader.cpp14
-rw-r--r--dom/script/ScriptLoader.h8
2 files changed, 11 insertions, 11 deletions
diff --git a/dom/script/ScriptLoader.h b/dom/script/ScriptLoader.h
index 46ed4e120..82a8512c0 100644
--- a/dom/script/ScriptLoader.h
+++ b/dom/script/ScriptLoader.h
@@ -74,8 +74,8 @@ public:
mProgress(Progress::Loading),
mIsInline(true),
mHasSourceMapURL(false),
- mIsDefer(false),
- mIsAsync(false),
+ mInDeferList(false),
+ mInAsyncList(false),
mIsNonAsyncScriptInserted(false),
mIsXSLT(false),
mIsCanceled(false),
@@ -159,8 +159,8 @@ public:
Progress mProgress; // Are we still waiting for a load to complete?
bool mIsInline; // Is the script inline or loaded?
bool mHasSourceMapURL; // Does the HTTP header have a source map url?
- bool mIsDefer; // True if we live in mDeferRequests.
- bool mIsAsync; // True if we live in mLoadingAsyncRequests or mLoadedAsyncRequests.
+ bool mInDeferList; // True if we live in mDeferRequests.
+ bool mInAsyncList; // True if we live in mLoadingAsyncRequests or mLoadedAsyncRequests.
bool mIsNonAsyncScriptInserted; // True if we live in mNonAsyncExternalScriptInsertedRequests
bool mIsXSLT; // True if we live in mXSLTRequests.
bool mIsCanceled; // True if we have been explicitly canceled.
diff --git a/dom/script/ScriptLoader.cpp b/dom/script/ScriptLoader.cpp
index afda82da0..69777c247 100644
--- a/dom/script/ScriptLoader.cpp
+++ b/dom/script/ScriptLoader.cpp
@@ -1358,7 +1358,7 @@ ScriptLoader::ProcessScriptElement(nsIScriptElement *aElement)
request->mJSVersion = version;
if (aElement->GetScriptAsync()) {
- request->mIsAsync = true;
+ request->mInAsyncList = true;
if (request->IsReadyToRun()) {
mLoadedAsyncRequests.AppendElement(request);
// The script is available already. Run it ASAP when the event
@@ -1469,7 +1469,7 @@ ScriptLoader::ProcessScriptElement(nsIScriptElement *aElement)
modReq->mBaseURL = mDocument->GetDocBaseURI();
if (aElement->GetScriptAsync()) {
- modReq->mIsAsync = true;
+ modReq->mInAsyncList = true;
mLoadingAsyncRequests.AppendElement(modReq);
} else {
AddDeferRequest(modReq);
@@ -2342,14 +2342,14 @@ ScriptLoader::HandleLoadError(ScriptLoadRequest *aRequest, nsresult aResult) {
SetModuleFetchFinishedAndResumeWaitingRequests(request, aResult);
}
- if (aRequest->mIsDefer) {
+ if (aRequest->mInDeferList) {
MOZ_ASSERT_IF(aRequest->IsModuleRequest(),
aRequest->AsModuleRequest()->IsTopLevel());
if (aRequest->isInList()) {
RefPtr<ScriptLoadRequest> req = mDeferRequests.Steal(aRequest);
FireScriptAvailable(aResult, req);
}
- } else if (aRequest->mIsAsync) {
+ } else if (aRequest->mInAsyncList) {
MOZ_ASSERT_IF(aRequest->IsModuleRequest(),
aRequest->AsModuleRequest()->IsTopLevel());
if (aRequest->isInList()) {
@@ -2423,10 +2423,10 @@ ScriptLoader::MaybeMoveToLoadedList(ScriptLoadRequest* aRequest)
{
MOZ_ASSERT(aRequest->IsReadyToRun());
// If it's async, move it to the loaded list. aRequest->mIsAsync really
// _should_ be in a list, but the consequences if it's not are bad enough we
// want to avoid trying to move it if it's not.
- if (aRequest->mIsAsync) {
+ if (aRequest->mInAsyncList) {
MOZ_ASSERT(aRequest->isInList());
if (aRequest->isInList()) {
RefPtr<ScriptLoadRequest> req = mLoadingAsyncRequests.Steal(aRequest);
@@ -2636,7 +2636,7 @@ ScriptLoader::PreloadURI(nsIURI *aURI, const nsAString &aCharset,
void
ScriptLoader::AddDeferRequest(ScriptLoadRequest* aRequest)
{
- aRequest->mIsDefer = true;
+ aRequest->mInDeferList = true;
mDeferRequests.AppendElement(aRequest);
if (mDeferEnabled && aRequest == mDeferRequests.getFirst() &&
mDocument && !mBlockingDOMContentLoaded) {
@@ -2423,10 +2423,10 @@ ScriptLoader::MaybeMoveToLoadedList(ScriptLoadRequest* aRequest)
{
MOZ_ASSERT(aRequest->IsReadyToRun());
- // If it's async, move it to the loaded list. aRequest->mIsAsync really
+ // If it's async, move it to the loaded list. aRequest->mInAsyncList really
// _should_ be in a list, but the consequences if it's not are bad enough we
// want to avoid trying to move it if it's not.